summaryrefslogtreecommitdiffstats
path: root/src/aboutklamav.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/aboutklamav.h')
-rw-r--r--src/aboutklamav.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/aboutklamav.h b/src/aboutklamav.h
index 0d3452c..a04f106 100644
--- a/src/aboutklamav.h
+++ b/src/aboutklamav.h
@@ -9,13 +9,13 @@
#include <config.h>
#endif
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
class KPrinter;
-class KToggleAction;
+class TDEToggleAction;
class KURL;
class TQLineEdit;
class TQComboBox;
@@ -23,8 +23,8 @@ class TQCheckBox;
class TQListBox;
class TQPushButton;
class TQLabel;
-class KProcess;
-class KConfig;
+class TDEProcess;
+class TDEConfig;
class KURLRequester;
namespace KlamAV
@@ -74,14 +74,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- //void saveProperties(KConfig *);
+ //void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- //void readProperties(KConfig *);
+ //void readProperties(TDEConfig *);
private slots:
@@ -108,8 +108,8 @@ private:
//AboutklamavView *m_view;
/* KPrinter *m_printer;
- KToggleAction *m_toolbarAction;
- KToggleAction *m_statusbarAction;*/
+ TDEToggleAction *m_toolbarAction;
+ TDEToggleAction *m_statusbarAction;*/
KlamAV::PageViewer* homepage;
KlamAV::TabWidget* tabBrowser;
signals:
@@ -126,7 +126,7 @@ protected slots:
private:
TQPushButton *about_button;
- KConfig *config;
+ TDEConfig *config;
TQComboBox *check_combo;
TQLabel *notes_label;
};
@@ -74,14 +74,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties